@@ -1,21 +1,23 @@
 /*
- * Copyright (c) Members of the EGEE Collaboration. 2010.
- * See http://www.eu-egee.org/partners/ for details on the copyright holders.
+ * Copyright (c) CERN 2013-2015
+ *
+ * Copyright (c) Members of the EMI Collaboration. 2010-2013
+ *  See  http://www.eu-emi.eu/partners for details on the copyright
+ *  holders.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *    http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
- *
- * Authors: Todor Manev  IT-GT CERN
  */
+
 #include <errno.h>
 #include "srmv2_space_management_functions.h"
 
@@ -235,7 +237,7 @@ char* srmv2_getbestspacetoken (struct srm_context *context,
 {
 	struct srm_getspacetokens_input getspacetoken_input;
 	struct srm_getspacetokens_output getspacetoken_output;
-	struct srm_getspacemd_input getspacemd_input;;
+	struct srm_getspacemd_input getspacemd_input;
 	int sav_errno = 0;
 	int i, ret, numtoken = -1;
 	SRM_LONG64 unusedsize = -1;
